@@ -1,4 +1,3 @@
-
 def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_score = 0.50, classification = 'Y', algo=None):
     
     """
@@ -83,7 +82,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     
     # Determine log-loss cutpoint
     actual=score_test['actual'].mean()
-    multi=10000
+    multi=100000
     class_ratio = [actual, 1-actual]
     class_ratio = [round(i, 3) for i in class_ratio]
     
@@ -95,9 +94,15 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     for i in range(multi):
         preds+=[class_ratio]
 
-    print(f'log-loss: values below {metrics.log_loss(actuals, preds)} are better than chance.\n\n')
-    
-    
+    try:
+        print(f'log-loss: values below {metrics.log_loss(actuals, preds)} are better than chance.\n\n')
+    except ValueError:
+        try:
+            multi=10000
+            print(f'log-loss: values below {metrics.log_loss(actuals, preds)} are better than chance.\n\n')
+        except ValueError:
+            print('Log-loss threshold could not be computed')
+            
     # Classification Metrics
     if classification == True:
         
@@ -132,6 +137,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         print('Recall: % of postive cases accurately classified. True Positives / (True Positives + False Negatives)')
         print('F1 Score: The harmonic mean between precision and recall.')
             
+    print(f'\n\nFeature List: \n{x_test.columns.tolist()}\n')
     
     # Lift Table
     # Compute Deciles
@@ -261,6 +267,4 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         return metricx, lift, classification_metricx
     
     else:
-        return metricx, lift
-    
-
+        return metricx, lift
\ No newline at end of file
